PyXMake Developer Guide: PyXMake.VTL.stm_make.bundle_pycodac Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Attributes | List of all members
PyXMake.VTL.stm_make.bundle_pycodac Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.bundle_pycodac:

## Public Attributes
| install_path
Public Attributes inherited from PyXMake.VTL.stm_make.pyx_bundle
| verbose
| source_path
| output_file_path
| scratch_path
| install_path

## Additional Inherited Members
Public Member Functions inherited from PyXMake.VTL.stm_make.pyx_bundle
def | initialize_options (self)
def | finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
def | run (self)
Static Public Attributes inherited from PyXMake.VTL.stm_make.pyx_bundle
string | description = "Compile a stand-alone installer using NSIS."
list | user_options

## Detailed Description

    Create an installer for STMLab using PyCODAC.

Definition at line 234 of file stm_make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/VTL/stm_make.py